@@ -1,9 +1,7 @@
 #!/usr/bin/env python
-
 import argparse
 import logging
 import os
-from igsr_archive.api import API
 
 logging.basicConfig(level=logging.DEBUG)
 
@@ -13,16 +11,23 @@ logger = logging.getLogger(__name__)
 parser = argparse.ArgumentParser(description='Fetch a certain FIRE object and its metadata')
 
 
-parser.add_argument('-s', '--settingsf', required=True,
+parser.add_argument('-s', '--settings', required=True,
                     help="Path to .ini file with settings")
 parser.add_argument('--firePath', required=True,
                     help="firePath of object to retrieve")
 parser.add_argument('--firepwd', help="FIRE api password. If not provided then it will try to guess"
                                       "the FIRE pwd from the $FIRE_PWD env variable")
 
+logger.info('Running script')
+
 args = parser.parse_args()
 
-logger.info('Running script')
+if not os.path.isfile(args.settings):
+    raise Exception(f"Config file provided using --settings option({args.settings}) not found!")
+# set the CONFIG_FILE env variable
+os.environ["CONFIG_FILE"] = os.path.abspath(args.settings)
+
+from igsr_archive.api import API
 
 firepwd = args.firepwd
 if args.firepwd is None:
@@ -30,12 +35,8 @@ if args.firepwd is None:
 
 assert firepwd, "$FIRE_PWD undefined"
 
-if not os.path.isfile(args.settingsf):
-    raise Exception(f"Config file provided using --settingsf option({args.settingsf}) not found!")
-
 # connection to FIRE api
-api = API(settingsf=args.settingsf,
-          pwd=firepwd)
+api = API(pwd=firepwd)
 
 fobject = api.fetch_object(firePath=args.firePath)
 
